@@ -155,7 +155,7 @@ class SlappResponseObject:
                     logging.error(f"Source was not specified in JSON: {source}")
                 else:
                     result.append(simple_source)
-        result.sort(key=lambda s: s.name)  # Sorting by name guaranteed - all sources should have a name.
+        result.sort(key=lambda s: s.name, reverse=True)  # Sorting by name guaranteed - all sources should have a name.
         return result
 
     def get_grouped_sources(self, sources: Union[Player, Team, List[UUID]]) -> Dict[str, List[SimpleSource]]:
@@ -164,6 +164,9 @@ class SlappResponseObject:
         result = {}
         for simple_source in simple_sources:
             result.setdefault(simple_source.tournament_name or '', []).append(simple_source)
+
+        for _, sources_for_tourney in result.items():
+            sources_for_tourney.sort(key=lambda s: s.name, reverse=True)
         return result
 
     def get_grouped_sources_text(self, sources: Union[Player, Team, List[UUID]]) -> List[str]:
